:mod:`npdl.activations`
=======================

.. automodule:: npdl.activations


Activations
-----------

.. autosummary::

   Activation
   Sigmoid
   Tanh
   ReLU
   Linear
   Softmax
   Elliot
   SymmetricElliot
   SoftPlus
   SoftSign


Detailed Description
--------------------

.. autoclass:: Activation
   :members:

.. autoclass:: Sigmoid
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: sigmoid-start
    :end-before: sigmoid-end

.. autoclass:: Tanh
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: tanh-start
    :end-before: tanh-end

.. autoclass:: ReLU
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: relu-start
    :end-before: relu-end

.. autoclass:: Linear
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: linear-start
    :end-before: linear-end

.. autoclass:: Softmax
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: softmax-start
    :end-before: softmax-end

.. autoclass:: Elliot
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: elliot-start
    :end-before: elliot-end

.. autoclass:: SymmetricElliot
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: symmetric-elliot-start
    :end-before: symmetric-elliot-end

.. autoclass:: SoftPlus
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: softplus-start
    :end-before: softplus-end

.. autoclass:: SoftSign
   :members:

.. literalinclude:: ../../npdl/activations.py
    :start-after: softsign-start
    :end-before: softsign-end

